@@ -3,8 +3,6 @@ Python wrapper for getting air quality data from GIOS.
 """
 import logging
 
-from aiohttp import ClientError
-
 _LOGGER = logging.getLogger(__name__)
 
 ATTR_AQI = "AQI"
@@ -43,8 +41,7 @@ class Gios:
         if not self.station_name:
             stations = await self._get_stations()
             if not stations:
-                _LOGGER.error("Invalid measuring stations list from GIOS API.")
-                return
+                raise ApiError("Invalid measuring stations list from GIOS API")
 
             for station in stations:
                 if station[ATTR_ID] == self.station_id:
@@ -53,16 +50,13 @@ class Gios:
                     self.station_name = station["stationName"]
             if not self.station_name:
                 raise NoStationError(
-                    f"{self.station_id} is not a valid measuring station ID."
+                    f"{self.station_id} is not a valid measuring station ID"
                 )
 
             self._station_data = await self._get_station()
 
         if not self._station_data:
-            _LOGGER.error("Invalid measuring station data from GIOS API.")
-            self.station_name = None
-            self.data = {}
-            return
+            raise ApiError("Invalid measuring station data from GIOS API")
 
         for sensor in self._station_data:
             data[sensor["param"]["paramCode"]] = {
@@ -81,13 +75,11 @@ class Gios:
                     elif sensor_data.get("values")[1][ATTR_VALUE]:
                         data[sensor][ATTR_VALUE] = sensor_data["values"][1][ATTR_VALUE]
                     else:
-                        raise ValueError
+                        raise ApiError("Invalid sensor data from GIOS API")
                 else:
                     invalid_sensors.append(sensor)
-        except (IndexError, KeyError, TypeError, ValueError):
-            _LOGGER.error("Invalid sensor data from GIOS API.")
-            self.data = {}
-            return
+        except (IndexError, KeyError, TypeError):
+            raise ApiError("Invalid sensor data from GIOS API")
 
         if invalid_sensors:
             for sensor in invalid_sensors:
@@ -106,9 +98,7 @@ class Gios:
                 "indexLevelName"
             ].lower()
         except (IndexError, KeyError, TypeError):
-            _LOGGER.error("Invalid index data from GIOS API")
-            self.data = {}
-            return
+            raise ApiError("Invalid index data from GIOS API")
 
         # For compatibility with Home Assistant UpdateDataCoordinator
         data["station_id"] = self.station_id
@@ -142,23 +132,14 @@ class Gios:
     async def _async_get(self, url):
         """Retreive data from GIOS API."""
         data = None
-        try:
-            async with self.session.get(url) as resp:
-                if resp.status != HTTP_OK:
-                    _LOGGER.warning("Invalid response from GIOS API: %s", resp.status)
-                    raise ApiError(resp.status)
-                data = await resp.json()
-        except ClientError as error:
-            _LOGGER.error("Invalid response from from GIOS API: %s", error)
-            return
+        async with self.session.get(url) as resp:
+            if resp.status != HTTP_OK:
+                _LOGGER.warning("Invalid response from GIOS API: %s", resp.status)
+                raise ApiError(resp.status)
+            data = await resp.json()
         _LOGGER.debug("Data retrieved from %s, status: %s", url, resp.status)
         return data
 
-    @property
-    def available(self):
-        """Return True is data is available."""
-        return bool(self.data)
-
 
 class ApiError(Exception):
     """Raised when GIOS API request ended in error."""
